Quick Start
-----------

To start using MARSI you need to install all the dependencies and the 
source code.

Optional:

1. Create a dir for the project (e.g. marsi)
2. Go to the folder and create a file setup.cfg (see bellow)

setup.cfg
```
[marsi]
prj_dir=<full_path_to_dir>

```

Otherwise the folder is will be create at `$HOME/.marsi`

The next step is to start `marsi`.

